summaryrefslogtreecommitdiffstats
path: root/src/H5Gent.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2005-12-26 05:28:18 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2005-12-26 05:28:18 (GMT)
commit83929ea716220890e41f923566aa5c89e8e735d3 (patch)
tree22193da0d9129fc7c06a57db35b2f4a57458cf50 /src/H5Gent.c
parentdb551ec15e771b4536c35cc6f3eabb7d28681510 (diff)
downloadhdf5-83929ea716220890e41f923566aa5c89e8e735d3.zip
hdf5-83929ea716220890e41f923566aa5c89e8e735d3.tar.gz
hdf5-83929ea716220890e41f923566aa5c89e8e735d3.tar.bz2
[svn-r11838] Purpose:
Bug fix Description: Retrieving an object's name could fail (in various ways) under certain circumstances (mostly having to do with mounted files). Solution: Re-write & simplify "get object name" code to fix error in a better way than adding yet another hack to the previous pile of hacks... :-) Platforms tested: FreeBSD 4.11 (sleipnir) h5committest
Diffstat (limited to 'src/H5Gent.c')
-rw-r--r--src/H5Gent.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/H5Gent.c b/src/H5Gent.c
index 08f7e77..e2e512b 100644
--- a/src/H5Gent.c
+++ b/src/H5Gent.c
@@ -327,34 +327,34 @@ H5G_ent_encode(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent)
*
* Notes: 'depth' parameter determines how much of the group entry
* structure we want to copy. The values are:
* H5G_COPY_SHALLOW - Copy all the fields from the source
* to the destination, including the user path and
* canonical path. (Destination "takes ownership" of
* user and canonical paths)
* H5G_COPY_DEEP - Copy all the fields from the source to
* the destination, deep copying the user and canonical
* paths.
*
*-------------------------------------------------------------------------
*/
herr_t
-H5G_ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5G_copy_depth_t depth)
+H5G_ent_copy(H5G_entry_t *dst, const H5G_entry_t *src, H5_copy_depth_t depth)
{
FUNC_ENTER_NOAPI_NOFUNC(H5G_ent_copy)
/* Check arguments */
HDassert(src);
HDassert(dst);
- HDassert(depth == H5G_COPY_SHALLOW || depth == H5G_COPY_DEEP);
+ HDassert(depth == H5_COPY_SHALLOW || depth == H5_COPY_DEEP);
/* Copy the top level information */
HDmemcpy(dst, src, sizeof(H5G_entry_t));
/* Deep copy the names */
- if(depth == H5G_COPY_DEEP) {
+ if(depth == H5_COPY_DEEP) {
/* Nothing currently */
;
- } else if(depth == H5G_COPY_SHALLOW) {
+ } else if(depth == H5_COPY_SHALLOW) {
/* Discarding 'const' qualifier OK - QAK */
H5G_ent_reset((H5G_entry_t *)src);
} /* end if */
@@ -327,34 +327,34 @@ H5G_ent_encode(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent)
* Notes: 'depth' parameter determines how much of the group entry
* structure we want to copy. The values are:
- * H5G_COPY_SHALLOW - Copy all the fields from the source
+ * H5_COPY_SHALLOW - Copy all the fields from the source
* to the destination, including the user path and
* canonical path. (Destination "takes ownership" of
@@ -327,34 +327,34 @@ H5G_ent_encode(H5F_t *f, uint8_t **pp, const H5G_entry_t *ent)
* canonical path. (Destination "takes ownership" of
* user and canonical paths)
- * H5G_COPY_DEEP - Copy all the fields from the source to
+ * H5_COPY_DEEP - Copy all the fields from the source to
* the destination, deep copying the user and canonical
* paths.